@@ -4,9 +4,10 @@ use strict;
 use warnings;
 use 5.008001;
 use Carp qw( croak );
+use FFI::Platypus::Function;
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '0.75_01'; # TRIAL VERSION
+our $VERSION = '0.76_01'; # TRIAL VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -270,18 +271,39 @@ sub type_meta
 
 sub function
 {
+  my $wrapper;
+  $wrapper = pop if ref $_[-1] eq 'CODE';
+
   my($self, $name, $args, $ret) = @_;
-  croak "usage \$ffi->function( name, [ arguments ], return_type)" unless @_ == 4;
+  croak "usage \$ffi->function( name, [ arguments ], return_type)" unless (@_ == 4) || (@_ == 5);
   my @args = map { $self->_type_lookup($_) || croak "unknown type: $_" } @$args;
   $ret = $self->_type_lookup($ret) || croak "unknown type: $ret";
   my $address = $name =~ /^-?[0-9]+$/ ? $name : $self->find_symbol($name);
   croak "unable to find $name" unless defined $address || $self->ignore_not_found;
   return unless defined $address;
-  FFI::Platypus::Function->new($self, $address, $self->{abi}, $ret, @args);
+  my $function = FFI::Platypus::Function::Function->new($self, $address, $self->{abi}, $ret, @args);
+  $wrapper
+    ? FFI::Platypus::Function::Wrapper->new($function, $wrapper)
+    : $function;
+}
+
+sub _function_meta
+{
+  # NOTE: may be upgraded to a documented function one day,
+  # but shouldn't be used externally as we will rename it
+  # if that happens.
+  my($self, $name, $meta, $args, $ret) = @_;
+  $args = ['opaque','int',@$args];
+  $self->function(
+    $name, $args, $ret, sub {
+      my $xsub = shift;
+      $xsub->($meta, scalar(@_), @_);
+    },
+  );
 }
 
 
-my $inner_counter=0;
+#my $inner_counter=0;
 
 sub attach
 {
@@ -296,30 +318,11 @@ sub attach
   croak "you tried to provide a perl name that looks like an address"
     if $perl_name =~ /^-?[0-9]+$/;
   
-  my $function = $self->function($c_name, $args, $ret);
+  my $function = $self->function($c_name, $args, $ret, $wrapper);
   
   if(defined $function)
   {
-    my($caller, $filename, $line) = caller;
-    $perl_name = join '::', $caller, $perl_name
-      unless $perl_name =~ /::/;
-    
-    my $attach_name = $perl_name;
-    if($wrapper)
-    {
-      $attach_name = "FFI::Platypus::Inner::xsub$inner_counter";
-      $inner_counter++;
-    }
-    
-    $function->attach($attach_name, "$filename:$line", $proto);
-    
-    if($wrapper)
-    {
-      my $inner_coderef = \&{$attach_name};
-      no strict 'refs';
-      # TODO: Sub::Name ?
-      *{$perl_name} = sub { $wrapper->($inner_coderef, @_) };
-    }
+    $function->attach($perl_name);
   }
   
   $self;
@@ -543,25 +546,11 @@ sub _have_pm
   $ok;
 }
 
-package FFI::Platypus::Function;
-
-our $VERSION = '0.75_01'; # TRIAL VERSION
-
-use overload '&{}' => sub {
-  my $ffi = shift;
-  sub { $ffi->call(@_) };
-};
-
-use overload 'bool' => sub {
-  my $ffi = shift;
-  return $ffi;
-};
-
 package FFI::Platypus::Type;
 
 use Carp qw( croak );
 
-our $VERSION = '0.75_01'; # TRIAL VERSION
+our $VERSION = '0.76_01'; # TRIAL VERSION
 
 sub new
 {
@@ -663,7 +652,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 0.75_01
+version 0.76_01
 
 =head1 SYNOPSIS
 
@@ -681,11 +670,11 @@ version 0.75_01
 
 =head1 DESCRIPTION
 
-Platypus is a library for creating interfaces to machine code libraries 
-written in languages like C, L<C++|FFI::Platypus::Lang::CPP>, 
-L<Fortran|FFI::Platypus::Lang::Fortran>, 
-L<Rust|FFI::Platypus::Lang::Rust>, 
-L<Pascal|FFI::Platypus::Lang::Pascal>. Essentially anything that gets 
+Platypus is a library for creating interfaces to machine code libraries
+written in languages like C, L<C++|FFI::Platypus::Lang::CPP>,
+L<Fortran|FFI::Platypus::Lang::Fortran>,
+L<Rust|FFI::Platypus::Lang::Rust>,
+L<Pascal|FFI::Platypus::Lang::Pascal>. Essentially anything that gets
 compiled into machine code.  This implementation uses C<libffi> to 
 accomplish this task.  C<libffi> is battle tested by a number of other 
 scripting and virtual machine languages, such as Python and Ruby to 
@@ -954,6 +943,8 @@ Examples:
 
  my $function = $ffi->function($name => \@argument_types => $return_type);
  my $function = $ffi->function($address => \@argument_types => $return_type);
+ my $function = $ffi->function($name => \@argument_types => $return_type, \&wrapper);
+ my $function = $ffi->function($address => \@argument_types => $return_type, \&wrapper);
 
 Returns an object that is similar to a code reference in that it can be 
 called like one.
@@ -980,6 +971,13 @@ Example: a C function could return the address of another C function
 that you might want to call, or modules such as L<FFI::TinyCC> produce 
 machine code at runtime that you can call from Platypus.
 
+[version 0.76]
+
+If the last argument is a code reference, then it will be used as a 
+wrapper around the function when called.  The first argument to the wrapper 
+will be the inner function, or if it is later attached an xsub.  This can be
+used if you need to verify/modify input/output data.
+
 Examples:
 
  my $function = $ffi->function('my_function_name', ['int', 'string'] => 'string');
@@ -990,9 +988,9 @@ Examples:
  $ffi->attach($name => \@argument_types => $return_type);
  $ffi->attach([$c_name => $perl_name] => \@argument_types => $return_type);
  $ffi->attach([$address => $perl_name] => \@argument_types => $return_type);
- $ffi->attach($name => \@argument_types => $return_type, sub { ... });
- $ffi->attach([$c_name => $perl_name] => \@argument_types => $return_type, sub { ... });
- $ffi->attach([$address => $perl_name] => \@argument_types => $return_type, sub { ... });
+ $ffi->attach($name => \@argument_types => $return_type, \&wrapper);
+ $ffi->attach([$c_name => $perl_name] => \@argument_types => $return_type, \&wrapper);
+ $ffi->attach([$address => $perl_name] => \@argument_types => $return_type, \&wrapper);
 
 Find and attach a C function as a real live Perl xsub.  The advantage of 
 attaching a function over using the L<function|/function> method is that 
